@@ -1,9 +1,11 @@
 from abc import ABCMeta
 from multiprocessing import cpu_count
+
 from concurrent.futures import ThreadPoolExecutor
 
 from boto import ec2
 
+from mangrove.mappings import ConnectionsMapping
 from mangrove.utils import get_boto_module
 from mangrove.exceptions import (
     MissingMethodError,
@@ -54,10 +56,10 @@ class ServicePool(object):
                  aws_access_key_id=None, aws_secret_access_key=None):
         self.module = get_boto_module(self._aws_module_name)
         self._executor = ThreadPoolExecutor(max_workers=cpu_count())
-        self._connections = {}
+        self._connections = ConnectionsMapping()
 
-        self._regions = regions or self._get_module_regions()
-        self._regions = set(self.regions)
+        self._regions_names = regions or self._get_module_regions()
+        self._regions_names = set(self._regions_names)
         self.default_region = default_region
 
         if connect is True:
@@ -66,7 +68,6 @@ class ServicePool(object):
                 aws_secret_access_key=aws_secret_access_key
             )
 
-
     def connect(self, aws_access_key_id=None, aws_secret_access_key=None):
         """Starts connections to pool's services
 
@@ -82,20 +83,16 @@ class ServicePool(object):
         """
         # For performances reasons, every regions connections are
         # made concurrently through the concurent.futures library.
-        future_connections = {}
-        for region in self.regions:
-            future_connections[region] = self._executor.submit(
+        for region in self._regions_names:
+            self._connections[region] = self._executor.submit(
                 self._connect_module_to_region,
                 region,
                 aws_access_key_id=aws_access_key_id,
                 aws_secret_access_key=aws_secret_access_key
             )
 
-        # Once every connection futures have been spawned, let's
-        # eval them and set a related key in connections store
-        # according to it.
-        for region, future in future_connections.iteritems():
-            self._connections[region] = future.result()
+        if self.default_region is not None:
+            self._connections.default = self.default_region
 
     def _connect_module_to_region(self, region, aws_access_key_id=None,
                                   aws_secret_access_key=None):
@@ -123,11 +120,10 @@ class ServicePool(object):
 
     @property
     def regions(self):
-        return self._regions
+        return self._connections
 
     def region(self, region_name):
-        """Access a pools specific region connections
-
+        """Access a pools specific region connections 
         :param  region_name: region connection to be accessed
         :type   region_name: string
         """
@@ -157,7 +153,7 @@ class ServicePool(object):
 
     @default_region.setter
     def default_region(self, value):
-        if value is not None and not value in self.regions:
+        if value is not None and not value in self._regions_names:
             raise DoesNotExistError(
                     "Cannot set default region to {}. "
                     "Please make sure you've added it to the pool".format(value)
@@ -173,7 +169,7 @@ class ServicePool(object):
         """
         region_client = self._connect_module_to_region(region_name)
         self._connections[region_name] = region_client
-        self._regions.add(region_name)
+        self._regions_names.add(region_name)
 
 class ServiceMixinPool(object):
     """Multiple AWS services connection pool wrapper class
@@ -206,9 +202,9 @@ class ServiceMixinPool(object):
         pool.s3.bucket('test')
         ...
 
-    :param  regions: AWS regions to connect the service to as
-                     a default every regions will be used.
-    :type   regions: list of strings
+    :param  connect: Should the pool init services regions connections
+                     on instanciation.
+    :type   connect: bool
 
     :param  aws_access_key_id: aws access key token (if not provided
                                AWS_ACCESS_KEY_ID will be fetched from
